@@ -9,7 +9,7 @@ use constant {
     F      => -1,
 };
 
-our $VERSION = 1.1; # local revision: d
+our $VERSION = 1.101; # local revision: d
 
 1;
 
@@ -216,30 +216,16 @@ John Baker C<< <johnb@listbrokers.com> >>
 Paul Miller C<< <jettero@cpan.org> >>
 
 I am using this software in my own projects...  If you find bugs, please please
-please let me know.
-
-I normally hang out on #perl on freenode, so you can try to get immediate
-gratification there if you like.  L<irc://irc.freenode.net/perl>
-
-There is also a mailing list with very light traffic that you might want to
-join: L<http://groups.google.com/group/stockmonkey/>.
+please let me know.  There is a mailing list with very light traffic that you
+might want to join: L<http://groups.google.com/group/stockmonkey/>.
 
 =head1 COPYRIGHT
 
-Copyright (c) 2010 Paul Miller
+Copyright (c) 2012 Paul Miller
 
 =head1 LICENSE
 
-This module is free software.  You can redistribute it and/or
-modify it under the terms of the Artistic License 2.0.
-
-This program is distributed in the hope that it will be useful,
-but without any warranty; without even the implied warranty of
-merchantability or fitness for a particular purpose.
-
-[This software may have had previous licenses, of which the current maintainer
-is completely unaware.  If this is so, it is possible the above license is
-incorrect or invalid.]
+This is released under the Artistic License. See L<perlartistic>.
 
 =head1 SEE ALSO
 
